# frozen_string_literal: true

module Hermes
  # HousingRequest serializer
  class RequiredDocumentSerializer < Hermes::ApplicationSerializer
    type 'required_documents'
    
    attributes :type,
               :validity_limit,
               :is_still_valid,
               :status,
               :validation_errors,
               :tagset_id,
               :tagsetLocation,
               :files,
               :category,
               :is_required_for_nud,
               :is_required_for_consultation,
               :is_required_for_application,
               :is_for_main_applicant,
               :dependent_infos,
               :disability_index,
               :applicant,
      
      def tagset_id
        object&.tagset_id
      end
    
    def is_still_valid
      !!object.validity_limit && object.validity_limit > DateTime.now.to_date
    end
    
    def status
      if object.status == "Pièce validée" && object.kyc_needed && (object.validity_limit && DateTime.current > object.validity_limit)
        "Date de validité dépassée"
      else
        object.status
      end
    end
    
    def type
      splitted_type = object.type.split("####")
    
      if (splitted_type[1])
        splitted_type[1]
      else
        splitted_type2 = object.type.split("****")
        if (splitted_type2[1])
          splitted_type2[1]
        else
        object.type
          end
      end
    end
    
    def dependent_infos
      splitted_type = object.type.split("####")
      if (splitted_type[1])
        return JSON(splitted_type[0])
      else
        nil
      end
    end
    
    def disability_index
      splitted_type = object.type.split("****")
      if (splitted_type[1])
        return JSON(splitted_type[0])
      else
        nil
      end
    end
    def files
      return unless object.doc_id
      res = []
      doc = Doc.find(object.doc_id)
      return unless doc
      res.push({
                 doc_id: object.doc_id.to_s,
                 filename: doc.title,
                 url: object.hermes_ged_link(object.file_url),
                 preview_url: object.hermes_ged_link(object.preview_url),
                 doc_data: object.smartify_urls(object.get_ged_doc_data)
               })
      res
    end
    
    def is_required_for_nud
      folder_id = instance_options[:folder_id]
      return unless folder_id
      object.folder_where_is_required_for_nud.include? (folder_id)
    end
    
    def is_required_for_consultation
      folder_id = instance_options[:folder_id]
      return unless folder_id
      object.folder_where_is_required_for_consultation.include? (folder_id)
    end
    
    def is_required_for_application
      folder_id = instance_options[:folder_id]
      return unless folder_id
      object.folder_where_is_required_for_application.include? (folder_id)
    end
    
    def is_for_main_applicant
      main_applicant_id = instance_options[:main_applicant_id]
      return unless main_applicant_id
      
      (object.applicant.id.to_s == main_applicant_id.to_s)
    end
    
    def applicant
      return nil unless object.applicant
      Hermes::ApplicantSerializer.new(
        object.applicant,
        scope: scope,
        root: false
      )
    end
  end
end
